@@ -313,6 +313,9 @@ ModuleExport void UnregisterAVSImage(void)
 */
 static MagickBooleanType WriteAVSImage(const ImageInfo *image_info,Image *image)
 {
+  long
+    y;
+
   MagickBooleanType
     status;
 
@@ -320,14 +323,13 @@ static MagickBooleanType WriteAVSImage(const ImageInfo *image_info,Image *image)
     scene;
 
   register const PixelPacket
-    *p;
+    *restrict p;
 
   register long
-    x,
-    y;
+    x;
 
   register unsigned char
-    *q;
+    *restrict q;
 
   ssize_t
     count;
@@ -377,9 +379,9 @@ static MagickBooleanType WriteAVSImage(const ImageInfo *image_info,Image *image)
       {
         *q++=ScaleQuantumToChar((Quantum) (QuantumRange-
           (image->matte != MagickFalse ? p->opacity : OpaqueOpacity)));
-        *q++=ScaleQuantumToChar(p->red);
-        *q++=ScaleQuantumToChar(p->green);
-        *q++=ScaleQuantumToChar(p->blue);
+        *q++=ScaleQuantumToChar(GetRedPixelComponent(p));
+        *q++=ScaleQuantumToChar(GetGreenPixelComponent(p));
+        *q++=ScaleQuantumToChar(GetBluePixelComponent(p));
         p++;
       }
       count=WriteBlob(image,(size_t) (q-pixels),pixels);
