@@ -1080,8 +1080,8 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   SetQuantumPack(quantum_info,dpx.image.image_element[0].packing == 0 ?
     MagickTrue : MagickFalse);
   image_view=AcquireCacheView(image);
-#if defined(MAGICKCORE_OPENMP_SUPPORT) && (_OPENMP > 200505)
-  #pragma omp parallel for schedule(static) shared(row,status,quantum_type)
+#if defined(MAGICKCORE_OPENMP_SUPPORT) && (_OPENMP > 202001)
+  #pragma omp parallel for schedule(static,1) shared(row,status,quantum_type)
 #endif
   for (y=0; y < (long) image->rows; y++)
   {
@@ -1106,7 +1106,7 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if (status == MagickFalse)
       continue;
     pixels=GetQuantumPixels(quantum_info);
-#if defined(MAGICKCORE_OPENMP_SUPPORT) && (_OPENMP > 200505)
+#if defined(MAGICKCORE_OPENMP_SUPPORT) && (_OPENMP > 202001)
   #pragma omp critical (MagickCore_ReadDPXImage)
 #endif
     {
@@ -1482,8 +1482,9 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
           dpx.image.image_element[i].descriptor=RGBComponentType;
           if (image->matte != MagickFalse)
             dpx.image.image_element[i].descriptor=RGBAComponentType;
-          if ((IsGrayImage(image,&image->exception) != MagickFalse) &&
-              (image->matte == MagickFalse))
+          if ((image_info->type != TrueColorType) &&
+              (image->matte == MagickFalse) &&
+              (IsGrayImage(image,&image->exception) != MagickFalse))
             dpx.image.image_element[i].descriptor=LumaComponentType;
           break;
         }
@@ -1574,10 +1575,12 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
     dpx.orientation.timestamp);
   value=GetDPXProperty(image_info,image,"dpx:orientation.device");
   if (value != (const char *) NULL)
-    (void) strncpy(dpx.orientation.device,value,
-      sizeof(dpx.orientation.device));
+    (void) strncpy(dpx.orientation.device,value,sizeof(dpx.orientation.device));
   offset+=WriteBlob(image,sizeof(dpx.orientation.device),(unsigned char *)
     dpx.orientation.device);
+  value=GetDPXProperty(image_info,image,"dpx:orientation.serial");
+  if (value != (const char *) NULL)
+    (void) strncpy(dpx.orientation.serial,value,sizeof(dpx.orientation.serial));
   offset+=WriteBlob(image,sizeof(dpx.orientation.serial),(unsigned char *)
     dpx.orientation.serial);
   for (i=0; i < 4; i++)
@@ -1793,9 +1796,9 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
     Convert pixel packets to DPX raster image.
   */
   quantum_info=AcquireQuantumInfo(image_info,image);
-  quantum_info->quantum=32;
-  quantum_info->pack=dpx.image.image_element[0].packing == 0 ? MagickTrue :
-    MagickFalse;
+  SetQuantumQuantum(quantum_info,32);
+  SetQuantumPack(quantum_info,dpx.image.image_element[0].packing == 0 ?
+    MagickTrue : MagickFalse);
   quantum_type=RGBQuantum;
   if (image->matte != MagickFalse)
     quantum_type=RGBAQuantum;
@@ -1809,8 +1812,8 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
     }
   extent=GetBytesPerRow(image->columns,image->matte != MagickFalse ? 4UL : 3UL,
     image->depth,MagickTrue);
-  if ((IsGrayImage(image,&image->exception) != MagickFalse) &&
-      (image->matte == MagickFalse))
+  if ((image_info->type != TrueColorType) && (image->matte == MagickFalse) &&
+      (IsGrayImage(image,&image->exception) != MagickFalse))
     {
       quantum_type=GrayQuantum;
       extent=GetBytesPerRow(image->columns,1UL,image->depth,MagickTrue);
