@@ -305,7 +305,7 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
       break;
     if ((channel & RedChannel) != 0)
       {
-        y=(long) (histogram_image->rows-scale*histogram[x].red+0.5);
+        y=(long) ceil(histogram_image->rows-scale*histogram[x].red-0.5);
         r=q+y;
         for ( ; y < (long) histogram_image->rows; y++)
         {
@@ -315,7 +315,7 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
       }
     if ((channel & GreenChannel) != 0)
       {
-        y=(long) (histogram_image->rows-scale*histogram[x].green+0.5);
+        y=(long) ceil(histogram_image->rows-scale*histogram[x].green-0.5);
         r=q+y;
         for ( ; y < (long) histogram_image->rows; y++)
         {
@@ -325,7 +325,7 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
       }
     if ((channel & BlueChannel) != 0)
       {
-        y=(long) (histogram_image->rows-scale*histogram[x].blue+0.5);
+        y=(long) ceil(histogram_image->rows-scale*histogram[x].blue-0.5);
         r=q+y;
         for ( ; y < (long) histogram_image->rows; y++)
         {
@@ -371,7 +371,7 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
   (void) CopyMagickString(histogram_image->filename,image_info->filename,
     MaxTextExtent);
   write_info=CloneImageInfo(image_info);
-  (void) SetImageInfo(write_info,MagickTrue,&image->exception);
+  (void) SetImageInfo(write_info,1,&image->exception);
   if (LocaleCompare(write_info->magick,"HISTOGRAM") == 0)
     (void) FormatMagickString(histogram_image->filename,MaxTextExtent,
       "miff:%s",write_info->filename);
