@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2010 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -60,6 +60,7 @@
 #include "magick/quantize.h"
 #include "magick/quantum.h"
 #include "magick/string_.h"
+#include "magick/string-private.h"
 #include "magick/utility.h"
 
 /*
@@ -157,6 +158,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
 {
 #define RGBTransformImageTag  "RGBTransform/Image"
 
+  CacheView
+    *image_view;
+
   ExceptionInfo
     *exception;
 
@@ -179,9 +183,6 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
     *y_map,
     *z_map;
 
-  CacheView
-    *image_view;
-
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
@@ -223,8 +224,8 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
             return(MagickFalse);
         }
       image_view=AcquireCacheView(image);
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1) shared(status)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4) shared(status)
 #endif
       for (y=0; y < (long) image->rows; y++)
       {
@@ -232,7 +233,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           x;
 
         register PixelPacket
-          *__restrict q;
+          *restrict q;
 
         if (status == MagickFalse)
           continue;
@@ -245,9 +246,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           }
         for (x=0; x < (long) image->columns; x++)
         {
-          q->red=RoundToQuantum((MagickRealType) (QuantumRange-q->red));
-          q->green=RoundToQuantum((MagickRealType) (QuantumRange-q->green));
-          q->blue=RoundToQuantum((MagickRealType) (QuantumRange-q->blue));
+          q->red=ClampToQuantum((MagickRealType) (QuantumRange-q->red));
+          q->green=ClampToQuantum((MagickRealType) (QuantumRange-q->green));
+          q->blue=ClampToQuantum((MagickRealType) (QuantumRange-q->blue));
           q++;
         }
         sync=SyncCacheViewAuthenticPixels(image_view,exception);
@@ -276,8 +277,8 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         }
       GetMagickPixelPacket(image,&zero);
       image_view=AcquireCacheView(image);
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1) shared(status)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4) shared(status)
 #endif
       for (y=0; y < (long) image->rows; y++)
       {
@@ -285,13 +286,13 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           pixel;
 
         register IndexPacket
-          *__restrict indexes;
+          *restrict indexes;
 
         register long
           x;
 
         register PixelPacket
-          *__restrict q;
+          *restrict q;
 
         if (status == MagickFalse)
           continue;
@@ -333,8 +334,8 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
             return(MagickFalse);
         }
       image_view=AcquireCacheView(image);
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1) shared(status)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4) shared(status)
 #endif
       for (y=0; y < (long) image->rows; y++)
       {
@@ -347,7 +348,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           x;
 
         register PixelPacket
-          *__restrict q;
+          *restrict q;
 
         if (status == MagickFalse)
           continue;
@@ -364,9 +365,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         for (x=0; x < (long) image->columns; x++)
         {
           ConvertRGBToHSB(q->red,q->green,q->blue,&hue,&saturation,&brightness);
-          q->red=RoundToQuantum((MagickRealType) QuantumRange*hue);
-          q->green=RoundToQuantum((MagickRealType) QuantumRange*saturation);
-          q->blue=RoundToQuantum((MagickRealType) QuantumRange*brightness);
+          q->red=ClampToQuantum((MagickRealType) QuantumRange*hue);
+          q->green=ClampToQuantum((MagickRealType) QuantumRange*saturation);
+          q->blue=ClampToQuantum((MagickRealType) QuantumRange*brightness);
           q++;
         }
         sync=SyncCacheViewAuthenticPixels(image_view,exception);
@@ -389,8 +390,8 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
             return(MagickFalse);
         }
       image_view=AcquireCacheView(image);
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1) shared(status)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4) shared(status)
 #endif
       for (y=0; y < (long) image->rows; y++)
       {
@@ -403,7 +404,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           x;
 
         register PixelPacket
-          *__restrict q;
+          *restrict q;
 
         if (status == MagickFalse)
           continue;
@@ -420,9 +421,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         for (x=0; x < (long) image->columns; x++)
         {
           ConvertRGBToHSL(q->red,q->green,q->blue,&hue,&saturation,&lightness);
-          q->red=RoundToQuantum((MagickRealType) QuantumRange*hue);
-          q->green=RoundToQuantum((MagickRealType) QuantumRange*saturation);
-          q->blue=RoundToQuantum((MagickRealType) QuantumRange*lightness);
+          q->red=ClampToQuantum((MagickRealType) QuantumRange*hue);
+          q->green=ClampToQuantum((MagickRealType) QuantumRange*saturation);
+          q->blue=ClampToQuantum((MagickRealType) QuantumRange*lightness);
           q++;
         }
         sync=SyncCacheViewAuthenticPixels(image_view,exception);
@@ -445,8 +446,8 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
             return(MagickFalse);
         }
       image_view=AcquireCacheView(image);
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1) shared(status)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4) shared(status)
 #endif
       for (y=0; y < (long) image->rows; y++)
       {
@@ -459,7 +460,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           x;
 
         register PixelPacket
-          *__restrict q;
+          *restrict q;
 
         if (status == MagickFalse)
           continue;
@@ -476,9 +477,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         for (x=0; x < (long) image->columns; x++)
         {
           ConvertRGBToHWB(q->red,q->green,q->blue,&hue,&whiteness,&blackness);
-          q->red=RoundToQuantum((MagickRealType) QuantumRange*hue);
-          q->green=RoundToQuantum((MagickRealType) QuantumRange*whiteness);
-          q->blue=RoundToQuantum((MagickRealType) QuantumRange*blackness);
+          q->red=ClampToQuantum((MagickRealType) QuantumRange*hue);
+          q->green=ClampToQuantum((MagickRealType) QuantumRange*whiteness);
+          q->blue=ClampToQuantum((MagickRealType) QuantumRange*blackness);
           q++;
         }
         sync=SyncCacheViewAuthenticPixels(image_view,exception);
@@ -501,8 +502,8 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
             return(MagickFalse);
         }
       image_view=AcquireCacheView(image);
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1) shared(status)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4) shared(status)
 #endif
       for (y=0; y < (long) image->rows; y++)
       {
@@ -518,7 +519,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           x;
 
         register PixelPacket
-          *__restrict q;
+          *restrict q;
 
         if (status == MagickFalse)
           continue;
@@ -539,9 +540,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         {
           ConvertRGBToXYZ(q->red,q->green,q->blue,&X,&Y,&Z);
           ConvertXYZToLab(X,Y,Z,&L,&a,&b);
-          q->red=RoundToQuantum((MagickRealType) QuantumRange*L);
-          q->green=RoundToQuantum((MagickRealType) QuantumRange*a);
-          q->blue=RoundToQuantum((MagickRealType) QuantumRange*b);
+          q->red=ClampToQuantum((MagickRealType) QuantumRange*L);
+          q->green=ClampToQuantum((MagickRealType) QuantumRange*a);
+          q->blue=ClampToQuantum((MagickRealType) QuantumRange*b);
           q++;
         }
         sync=SyncCacheViewAuthenticPixels(image_view,exception);
@@ -573,19 +574,19 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
       /*
         Transform RGB to Log colorspace.
       */
-      density=2.03728;
+      density=DisplayGamma;
       gamma=DisplayGamma;
       value=GetImageProperty(image,"gamma");
       if (value != (const char *) NULL)
-        gamma=1.0/atof(value) != 0.0 ? atof(value) : 1.0;
+        gamma=1.0/StringToDouble(value) != 0.0 ? StringToDouble(value) : 1.0;
       reference_black=ReferenceBlack;
       value=GetImageProperty(image,"reference-black");
       if (value != (const char *) NULL)
-        reference_black=atof(value);
+        reference_black=StringToDouble(value);
       reference_white=ReferenceWhite;
       value=GetImageProperty(image,"reference-white");
       if (value != (const char *) NULL)
-        reference_white=atof(value);
+        reference_white=StringToDouble(value);
       logmap=(Quantum *) AcquireQuantumMemory((size_t) MaxMap+1UL,
         sizeof(*logmap));
       if (logmap == (Quantum *) NULL)
@@ -593,16 +594,16 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           image->filename);
       black=pow(10.0,(reference_black-reference_white)*(gamma/density)*
         0.002/0.6);
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4)
 #endif
       for (i=0; i <= (long) MaxMap; i++)
         logmap[i]=ScaleMapToQuantum((MagickRealType) (MaxMap*(reference_white+
           log10(black+((MagickRealType) i/MaxMap)*(1.0-black))/((gamma/density)*
           0.002/0.6))/1024.0+0.5));
       image_view=AcquireCacheView(image);
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1) shared(status)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4) shared(status)
 #endif
       for (y=0; y < (long) image->rows; y++)
       {
@@ -610,7 +611,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           x;
 
         register PixelPacket
-          *__restrict q;
+          *restrict q;
 
         if (status == MagickFalse)
           continue;
@@ -670,8 +671,8 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
       */
       primary_info.y=(double) (MaxMap+1.0)/2.0;
       primary_info.z=(double) (MaxMap+1.0)/2.0;
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4)
 #endif
       for (i=0; i <= (long) MaxMap; i++)
       {
@@ -695,8 +696,8 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
 
           G = 0.29900*R+0.58700*G+0.11400*B
       */
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4)
 #endif
       for (i=0; i <= (long) MaxMap; i++)
       {
@@ -728,8 +729,8 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
       */
       primary_info.y=(double) (MaxMap+1.0)/2.0;
       primary_info.z=(double) (MaxMap+1.0)/2.0;
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4)
 #endif
       for (i=0; i <= (long) MaxMap; i++)
       {
@@ -752,8 +753,8 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
 
           G = 0.21260*R+0.71520*G+0.07220*B
       */
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4)
 #endif
       for (i=0; i <= (long) MaxMap; i++)
       {
@@ -783,8 +784,8 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
       */
       primary_info.y=(double) (MaxMap+1.0)/2.0;
       primary_info.z=(double) (MaxMap+1.0)/2.0;
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4)
 #endif
       for (i=0; i <= (long) MaxMap; i++)
       {
@@ -809,8 +810,8 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           G = 0.0*R+0.1*G+0.0*B
           B = 0.0*R+0.0*G+1.0*B
       */
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4)
 #endif
       for (i=0; i <= (long) MaxMap; i++)
       {
@@ -839,24 +840,24 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
       /*
         Initialize CIE XYZ tables (ITU-R 709 RGB):
 
-          X = 0.4124240*R+0.3575790*G+0.1804640*B
-          Y = 0.2126560*R+0.7151580*G+0.0721856*B
-          Z = 0.0193324*R+0.1191930*G+0.9504440*B
+          X = 0.4124564*R+0.3575761*G+0.1804375*B
+          Y = 0.2126729*R+0.7151522*G+0.0721750*B
+          Z = 0.0193339*R+0.1191920*G+0.9503041*B
       */
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4)
 #endif
       for (i=0; i <= (long) MaxMap; i++)
       {
-        x_map[i].x=0.4124240f*(MagickRealType) i;
-        y_map[i].x=0.3575790f*(MagickRealType) i;
-        z_map[i].x=0.1804640f*(MagickRealType) i;
-        x_map[i].y=0.2126560f*(MagickRealType) i;
-        y_map[i].y=0.7151580f*(MagickRealType) i;
-        z_map[i].y=0.0721856f*(MagickRealType) i;
-        x_map[i].z=0.0193324f*(MagickRealType) i;
-        y_map[i].z=0.1191930f*(MagickRealType) i;
-        z_map[i].z=0.9504440f*(MagickRealType) i;
+        x_map[i].x=0.4124564f*(MagickRealType) i;
+        y_map[i].x=0.3575761f*(MagickRealType) i;
+        z_map[i].x=0.1804375f*(MagickRealType) i;
+        x_map[i].y=0.2126729f*(MagickRealType) i;
+        y_map[i].y=0.7151522f*(MagickRealType) i;
+        z_map[i].y=0.0721750f*(MagickRealType) i;
+        x_map[i].z=0.0193339f*(MagickRealType) i;
+        y_map[i].z=0.1191920f*(MagickRealType) i;
+        z_map[i].z=0.9503041f*(MagickRealType) i;
       }
       break;
     }
@@ -913,8 +914,8 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
       */
       primary_info.y=(double) (MaxMap+1.0)/2.0;
       primary_info.z=(double) (MaxMap+1.0)/2.0;
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4)
 #endif
       for (i=0; i <= (long) MaxMap; i++)
       {
@@ -944,8 +945,8 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
       */
       primary_info.y=(double) (MaxMap+1.0)/2.0;
       primary_info.z=(double) (MaxMap+1.0)/2.0;
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4)
 #endif
       for (i=0; i <= (long) MaxMap; i++)
       {
@@ -976,8 +977,8 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
       */
       primary_info.y=(double) (MaxMap+1.0)/2.0;
       primary_info.z=(double) (MaxMap+1.0)/2.0;
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4)
 #endif
       for (i=0; i <= (long) MaxMap; i++)
       {
@@ -1006,8 +1007,8 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         Convert DirectClass image.
       */
       image_view=AcquireCacheView(image);
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1) shared(status)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4) shared(status)
 #endif
       for (y=0; y < (long) image->rows; y++)
       {
@@ -1018,7 +1019,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           x;
 
         register PixelPacket
-          *__restrict q;
+          *restrict q;
 
         register unsigned long
           blue,
@@ -1058,7 +1059,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
             MagickBooleanType
               proceed;
 
-#if defined(_OPENMP) && (_OPENMP >= 200203)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
   #pragma omp critical (MagickCore_RGBTransformImage)
 #endif
             proceed=SetImageProgress(image,RGBTransformImageTag,progress++,
@@ -1239,7 +1240,6 @@ static inline void ConvertLabToXYZ(const double L,const double a,const double b,
   double *X,double *Y,double *Z)
 {
   double
-    cube,
     x,
     y,
     z;
@@ -1247,22 +1247,19 @@ static inline void ConvertLabToXYZ(const double L,const double a,const double b,
   assert(X != (double *) NULL);
   assert(Y != (double *) NULL);
   assert(Z != (double *) NULL);
-  y=(100.0*L+16.0)/116.0;
-  x=255.0*(a > 0.5 ? a-1.0 : a)/500.0+y;
-  z=y-255.0*(b > 0.5 ? b-1.0 : b)/200.0;
-  cube=y*y*y;
-  if (cube > 0.008856)
-    y=cube;
-  else
-    y=(y-16.0/116.0)/7.787;
-  cube=x*x*x;
-  if (cube > 0.008856)
-    x=cube;
+  y=((2.0*L-1.0)+0.160)/1.160;
+  x=(2.0*a-1.0)/5.000+y;
+  z=y-(2.0*b-1.0)/2.000;
+  if ((x*x*x) > (216.0/24389.0))
+    x=x*x*x;
   else
     x=(x-16.0/116.0)/7.787;
-  cube=z*z*z;
-  if (cube > 0.008856)
-    z=cube;
+  if ((y*y*y) > (216.0/24389.0))
+    y=y*y*y;
+  else
+    y=(y-16.0/116.0)/7.787;
+  if ((z*z*z) > (216.0/24389.0))
+    z=z*z*z;
   else
     z=(z-16.0/116.0)/7.787;
   *X=0.9504559271*x;
@@ -1293,24 +1290,12 @@ static inline void ConvertXYZToRGB(const double x,const double y,const double z,
   assert(red != (Quantum *) NULL);
   assert(green != (Quantum *) NULL);
   assert(blue != (Quantum *) NULL);
-  r=3.2404542*x-1.5371385*y-0.4985314*z;
-  g=(-0.9692660*x+1.8760108*y+0.0415560*z);
-  b=0.0556434*x-0.2040259*y+1.0572252*z;
-  if (r > 0.0031308)
-    r=1.055*pow(r,1.0/2.4)-0.055;
-  else
-    r*=12.92;
-  if (g > 0.0031308)
-    g=1.055*pow(g,1.0/2.4)-0.055;
-  else
-    g*=12.92;
-  if (b > 0.0031308)
-    b=1.055*pow(b,1.0/2.4)-0.055;
-  else
-    b*=12.92;
-  *red=RoundToQuantum((MagickRealType) QuantumRange*r);
-  *green=RoundToQuantum((MagickRealType) QuantumRange*g);
-  *blue=RoundToQuantum((MagickRealType) QuantumRange*b);
+  r=3.2407100*x-1.5372600*y-0.4985710*z;
+  g=(-0.9692580*x+1.8759900*y+0.0415557*z);
+  b=0.0556352*x-0.2039960*y+1.0570700*z;
+  *red=ClampToQuantum((MagickRealType) QuantumRange*r);
+  *green=ClampToQuantum((MagickRealType) QuantumRange*g);
+  *blue=ClampToQuantum((MagickRealType) QuantumRange*b);
 }
 
 static inline void ConvertCMYKToRGB(MagickPixelPacket *pixel)
@@ -1364,6 +1349,9 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
     };
 #endif
 
+  CacheView
+    *image_view;
+
   ExceptionInfo
     *exception;
 
@@ -1382,9 +1370,6 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
     *x_map,
     *z_map;
 
-  CacheView
-    *image_view;
-
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
@@ -1419,8 +1404,8 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
             return(MagickFalse);
         }
       image_view=AcquireCacheView(image);
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1) shared(status)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4) shared(status)
 #endif
       for (y=0; y < (long) image->rows; y++)
       {
@@ -1431,7 +1416,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           x;
 
         register PixelPacket
-          *__restrict q;
+          *restrict q;
 
         if (status == MagickFalse)
           continue;
@@ -1444,9 +1429,9 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           }
         for (x=0; x < (long) image->columns; x++)
         {
-          q->red=RoundToQuantum((MagickRealType) (QuantumRange-q->red));
-          q->green=RoundToQuantum((MagickRealType) (QuantumRange-q->green));
-          q->blue=RoundToQuantum((MagickRealType) (QuantumRange-q->blue));
+          q->red=ClampToQuantum((MagickRealType) (QuantumRange-q->red));
+          q->green=ClampToQuantum((MagickRealType) (QuantumRange-q->green));
+          q->blue=ClampToQuantum((MagickRealType) (QuantumRange-q->blue));
           q++;
         }
         sync=SyncCacheViewAuthenticPixels(image_view,exception);
@@ -1475,8 +1460,8 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
         }
       GetMagickPixelPacket(image,&zero);
       image_view=AcquireCacheView(image);
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1) shared(status)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4) shared(status)
 #endif
       for (y=0; y < (long) image->rows; y++)
       {
@@ -1487,13 +1472,13 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           pixel;
 
         register IndexPacket
-          *__restrict indexes;
+          *restrict indexes;
 
         register long
           x;
 
         register PixelPacket
-          *__restrict q;
+          *restrict q;
 
         if (status == MagickFalse)
           continue;
@@ -1535,8 +1520,8 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
             return(MagickFalse);
         }
       image_view=AcquireCacheView(image);
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1) shared(status)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4) shared(status)
 #endif
       for (y=0; y < (long) image->rows; y++)
       {
@@ -1552,7 +1537,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           x;
 
         register PixelPacket
-          *__restrict q;
+          *restrict q;
 
         if (status == MagickFalse)
           continue;
@@ -1593,8 +1578,8 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
             return(MagickFalse);
         }
       image_view=AcquireCacheView(image);
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1) shared(status)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4) shared(status)
 #endif
       for (y=0; y < (long) image->rows; y++)
       {
@@ -1610,7 +1595,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           x;
 
         register PixelPacket
-          *__restrict q;
+          *restrict q;
 
         if (status == MagickFalse)
           continue;
@@ -1651,8 +1636,8 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
             return(MagickFalse);
         }
       image_view=AcquireCacheView(image);
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1) shared(status)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4) shared(status)
 #endif
       for (y=0; y < (long) image->rows; y++)
       {
@@ -1668,7 +1653,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           x;
 
         register PixelPacket
-          *__restrict q;
+          *restrict q;
 
         if (status == MagickFalse)
           continue;
@@ -1709,8 +1694,8 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
             return(MagickFalse);
         }
       image_view=AcquireCacheView(image);
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1) shared(status)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4) shared(status)
 #endif
       for (y=0; y < (long) image->rows; y++)
       {
@@ -1729,7 +1714,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           x;
 
         register PixelPacket
-          *__restrict q;
+          *restrict q;
 
         if (status == MagickFalse)
           continue;
@@ -1779,19 +1764,19 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
       /*
         Transform Log to RGB colorspace.
       */
-      density=2.03728;
+      density=DisplayGamma;
       gamma=DisplayGamma;
       value=GetImageProperty(image,"gamma");
       if (value != (const char *) NULL)
-        gamma=1.0/atof(value) != 0.0 ? atof(value) : 1.0;
+        gamma=1.0/StringToDouble(value) != 0.0 ? StringToDouble(value) : 1.0;
       reference_black=ReferenceBlack;
       value=GetImageProperty(image,"reference-black");
       if (value != (const char *) NULL)
-        reference_black=atof(value);
+        reference_black=StringToDouble(value);
       reference_white=ReferenceWhite;
       value=GetImageProperty(image,"reference-white");
       if (value != (const char *) NULL)
-        reference_white=atof(value);
+        reference_white=StringToDouble(value);
       logmap=(Quantum *) AcquireQuantumMemory((size_t) MaxMap+1UL,
         sizeof(*logmap));
       if (logmap == (Quantum *) NULL)
@@ -1802,7 +1787,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
       for (i=0; i <= (long) (reference_black*MaxMap/1024.0); i++)
         logmap[i]=(Quantum) 0;
       for ( ; i < (long) (reference_white*MaxMap/1024.0); i++)
-        logmap[i]=RoundToQuantum((MagickRealType) QuantumRange/(1.0-black)*
+        logmap[i]=ClampToQuantum((MagickRealType) QuantumRange/(1.0-black)*
           (pow(10.0,(1024.0*i/MaxMap-reference_white)*
           (gamma/density)*0.002/0.6)-black));
       for ( ; i <= (long) MaxMap; i++)
@@ -1810,8 +1795,8 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
       if (SetImageStorageClass(image,DirectClass) == MagickFalse)
         return(MagickFalse);
       image_view=AcquireCacheView(image);
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1) shared(status)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4) shared(status)
 #endif
       for (y=0; y < (long) image->rows; y++)
       {
@@ -1822,7 +1807,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           x;
 
         register PixelPacket
-          *__restrict q;
+          *restrict q;
 
         if (status == MagickFalse)
           continue;
@@ -1889,8 +1874,8 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
         I and Q, normally -0.5 through 0.5, must be normalized to the range 0
         through QuantumRange.
       */
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4)
 #endif
       for (i=0; i <= (long) MaxMap; i++)
       {
@@ -1924,8 +1909,8 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
         Cb and Cr, normally -0.5 through 0.5, must be normalized to the range 0
         through QuantumRange.
       */
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4)
 #endif
       for (i=0; i <= (long) MaxMap; i++)
       {
@@ -1957,8 +1942,8 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
         Cb and Cr, normally -0.5 through 0.5, must be normalized to the range 0
         through QuantumRange.
       */
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4)
 #endif
       for (i=0; i <= (long) MaxMap; i++)
       {
@@ -1987,8 +1972,8 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           G = 0.0*R+1.0*G+0.0*B
           B = 0.0*R+0.0*G+1.0*B
       */
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4)
 #endif
       for (i=0; i <= (long) MaxMap; i++)
       {
@@ -2009,24 +1994,24 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
       /*
         Initialize CIE XYZ tables (ITU R-709 RGB):
 
-          R =  3.2407100*X-1.5372600*Y-0.4985710*Z
-          G = -0.9692580*X+1.8759900*Y+0.0415557*Z
-          B =  0.0556352*X-0.2039960*Y+1.0570700*Z
+          R =  3.2404542*X-1.5371385*Y-0.4985314*Z
+          G = -0.9692660*X+1.8760108*Y+0.0415560*Z
+          B =  0.0556434*X-0.2040259*Y+1.057225*Z
       */
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4)
 #endif
       for (i=0; i <= (long) MaxMap; i++)
       {
-        x_map[i].x=3.2407100f*(MagickRealType) i;
-        x_map[i].y=(-0.9692580f)*(MagickRealType) i;
-        x_map[i].z=0.0556352f*(MagickRealType) i;
-        y_map[i].x=(-1.5372600f)*(MagickRealType) i;
-        y_map[i].y=1.8759900f*(MagickRealType) i;
-        y_map[i].z=(-0.2039960f)*(MagickRealType) i;
-        z_map[i].x=(-0.4985710f)*(MagickRealType) i;
-        z_map[i].y=0.0415557f*(MagickRealType) i;
-        z_map[i].z=1.0570700f*(MagickRealType) i;
+        x_map[i].x=3.2404542f*(MagickRealType) i;
+        x_map[i].y=(-0.9692660f)*(MagickRealType) i;
+        x_map[i].z=0.0556434f*(MagickRealType) i;
+        y_map[i].x=(-1.5371385f)*(MagickRealType) i;
+        y_map[i].y=1.8760108f*(MagickRealType) i;
+        y_map[i].z=(-0.2040259f)*(MagickRealType) i;
+        z_map[i].x=(-0.4985314f)*(MagickRealType) i;
+        z_map[i].y=0.0415560f*(MagickRealType) i;
+        z_map[i].z=1.0572252f*(MagickRealType) i;
       }
       break;
     }
@@ -2041,8 +2026,8 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
 
         YCC is scaled by 1.3584.  C1 zero is 156 and C2 is at 137.
       */
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4)
 #endif
       for (i=0; i <= (long) MaxMap; i++)
       {
@@ -2074,8 +2059,8 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
         I and Q, normally -0.5 through 0.5, must be normalized to the range 0
         through QuantumRange.
       */
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4)
 #endif
       for (i=0; i <= (long) MaxMap; i++)
       {
@@ -2109,8 +2094,8 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
         Pb and Pr, normally -0.5 through 0.5, must be normalized to the range 0
         through QuantumRange.
       */
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4)
 #endif
       for (i=0; i <= (long) MaxMap; i++)
       {
@@ -2143,8 +2128,8 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
         U and V, normally -0.5 through 0.5, must be normalized to the range 0
         through QuantumRange.
       */
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4)
 #endif
       for (i=0; i <= (long) MaxMap; i++)
       {
@@ -2177,8 +2162,8 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
         Convert DirectClass image.
       */
       image_view=AcquireCacheView(image);
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1) shared(status)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4) shared(status)
 #endif
       for (y=0; y < (long) image->rows; y++)
       {
@@ -2192,7 +2177,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           x;
 
         register PixelPacket
-          *__restrict q;
+          *restrict q;
 
         if (status == MagickFalse)
           continue;
@@ -2268,7 +2253,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
             MagickBooleanType
               proceed;
 
-#if defined(_OPENMP) && (_OPENMP >= 200203)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
   #pragma omp critical (MagickCore_TransformRGBImage)
 #endif
             proceed=SetImageProgress(image,TransformRGBImageTag,progress++,
@@ -2286,8 +2271,8 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
         Convert PseudoClass image.
       */
       image_view=AcquireCacheView(image);
-#if defined(_OPENMP) && (_OPENMP >= 200203)
-  #pragma omp parallel for schedule(static,1) shared(status)
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(dynamic,4) shared(status)
 #endif
       for (i=0; i < (long) image->colors; i++)
       {
