@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2009 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2010 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -318,7 +318,8 @@ typedef struct _DrawInfo
 
   double
     kerning,
-    interword_spacing;
+    interword_spacing,
+    interline_spacing;
 } DrawInfo;
 
 typedef struct _PrimitiveInfo
