@@ -94,13 +94,26 @@
 #include "magick/utility.h"
 #include "magick/version.h"
 #if defined(MAGICKCORE_LCMS_DELEGATE)
-#if defined(MAGICKCORE_HAVE_LCMS_LCMS_H)
+#if defined(MAGICKCORE_HAVE_LCMS_LCMS2_H)
+#include <lcms/lcms2.h>
+#elif defined(MAGICKCORE_HAVE_LCMS2_H)
+#include "lcms2.h"
+#elif defined(MAGICKCORE_HAVE_LCMS_LCMS_H)
 #include <lcms/lcms.h>
 #else
 #include "lcms.h"
 #endif
 #endif
 
+/*
+  Define declarations.
+*/
+#if defined(MAGICKCORE_LCMS_DELEGATE)
+#if defined(LCMS_VERSION) && (LCMS_VERSION < 2000)
+#define cmsUInt32Number  DWORD
+#endif
+#endif
+
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -201,30 +214,17 @@ static int PrintChannelStatistics(FILE *file,const ChannelType channel,
   "      mean: %g (%g)\n      standard deviation: %g (%g)\n"  \
   "      kurtosis: %g\n      skewness: %g\n"
 
-  double
-    maxima,
-    mean,
-    minima;
-
   int
     status;
 
-  minima=channel_statistics[channel].minima;
-  maxima=channel_statistics[channel].maxima;
-  mean=channel_statistics[channel].mean;
-  if (channel == AlphaChannel)
-    {
-      minima=QuantumRange-minima;
-      maxima=QuantumRange-maxima;
-      mean=QuantumRange-mean;
-    }
-  status=fprintf(file,StatisticsFormat,name,(Quantum) (scale*minima),minima/
-    (double) QuantumRange,(Quantum) (maxima/scale),maxima/(double) QuantumRange,
-    scale*mean,mean/(double) QuantumRange,
-    scale*channel_statistics[channel].standard_deviation,
-    channel_statistics[channel].standard_deviation/(double)
-    QuantumRange,channel_statistics[channel].kurtosis,
-    channel_statistics[channel].skewness);
+  status=fprintf(file,StatisticsFormat,name,(Quantum) (scale*
+    channel_statistics[channel].minima+0.5),channel_statistics[channel].minima/
+    (double) QuantumRange,(Quantum) (scale*channel_statistics[channel].maxima+
+    0.5),channel_statistics[channel].maxima/(double) QuantumRange,scale*
+    channel_statistics[channel].mean,channel_statistics[channel].mean/
+    (double) QuantumRange,scale*channel_statistics[channel].standard_deviation,
+    channel_statistics[channel].standard_deviation/(double) QuantumRange,
+    channel_statistics[channel].kurtosis,channel_statistics[channel].skewness);
   return(status);
 }
 
@@ -344,7 +344,7 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
       if (GetBlobSize(image) != 0)
         {
           (void) FormatMagickSize(GetBlobSize(image),MagickFalse,format);
-          (void) fprintf(file,"%s ",format);
+          (void) fprintf(file,"%sB ",format);
         }
       (void) fprintf(file,"%0.3fu %ld:%02ld.%03ld",user_time,(long)
         (elapsed_time/60.0),(long) floor(fmod(elapsed_time,60.0)),
@@ -863,15 +863,33 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
               icc_profile;
 
             icc_profile=cmsOpenProfileFromMem(GetStringInfoDatum(profile),
-              (DWORD) GetStringInfoLength(profile));
+              (cmsUInt32Number) GetStringInfoLength(profile));
             if (icc_profile != (cmsHPROFILE *) NULL)
               {
+#if defined(LCMS_VERSION) && (LCMS_VERSION < 2000)
                 const char
                   *name;
 
                 name=cmsTakeProductName(icc_profile);
                 if (name != (const char *) NULL)
                   (void) fprintf(file,"      %s\n",name);
+#else
+                char
+                  info[MaxTextExtent];
+
+                (void) cmsGetProfileInfoASCII(icc_profile,cmsInfoDescription,
+                  "en","US",info,MaxTextExtent);
+                (void) fprintf(file,"      Description: %s\n",info);
+                (void) cmsGetProfileInfoASCII(icc_profile,cmsInfoManufacturer,
+                  "en","US",info,MaxTextExtent);
+                (void) fprintf(file,"      Manufacturer: %s\n",info);
+                (void) cmsGetProfileInfoASCII(icc_profile,cmsInfoModel,"en",
+                  "US",info,MaxTextExtent);
+                (void) fprintf(file,"      Model: %s\n",info);
+                (void) cmsGetProfileInfoASCII(icc_profile,cmsInfoCopyright,
+                  "en","US",info,MaxTextExtent);
+                (void) fprintf(file,"      Copyright: %s\n",info);
+#endif
                 (void) cmsCloseProfile(icc_profile);
               }
           }
@@ -1041,7 +1059,7 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
   (void) fprintf(file,"  Tainted: %s\n",MagickOptionToMnemonic(
     MagickBooleanOptions,(long) image->taint));
   (void) FormatMagickSize(GetBlobSize(image),MagickFalse,format);
-  (void) fprintf(file,"  Filesize: %s\n",format);
+  (void) fprintf(file,"  Filesize: %sB\n",format);
   (void) FormatMagickSize((MagickSizeType) image->columns*image->rows,
      MagickFalse,format);
   (void) fprintf(file,"  Number pixels: %s\n",format);
