@@ -985,7 +985,7 @@ MagickExport StringInfo *FileToStringInfo(const char *filename,
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  FormatMagickSize() converts a size to a human readable format, for example,
-%  14kb, 234mb, 2.7gb, or 3.0tb.  Scaling is done by repetitively dividing by
+%  14k, 234m, 2.7g, or 3.0t.  Scaling is done by repetitively dividing by
 %  1000.
 %
 %  The format of the FormatMagickSize method is:
@@ -1021,11 +1021,11 @@ MagickExport long FormatMagickSize(const MagickSizeType size,
   static const char
     *bi_units[] =
     {
-      "b", "KiB", "MiB", "GiB", "TiB", "PiB", "EiB", "ZiB", "YiB", (char *) NULL
+      "", "Ki", "Mi", "Gi", "Ti", "Pi", "Ei", "Zi", "Yi", (char *) NULL
     },
     *traditional_units[] =
     {
-      "b", "KB", "MB", "GB", "TB", "PB", "EB", "ZB", "YB", (char *) NULL
+      "", "K", "M", "G", "T", "P", "E", "Z", "Y", (char *) NULL
     };
 
   bytes=1000.0;
@@ -1334,7 +1334,7 @@ MagickExport const char *GetStringInfoPath(const StringInfo *string_info)
 %
 %  The format of the LocaleCompare method is:
 %
-%      long LocaleCompare(const char *p,const char *q)
+%      int LocaleCompare(const char *p,const char *q)
 %
 %  A description of each parameter follows:
 %
@@ -1343,7 +1343,7 @@ MagickExport const char *GetStringInfoPath(const StringInfo *string_info)
 %    o q: A pointer to a character string to compare to p.
 %
 */
-MagickExport long LocaleCompare(const char *p,const char *q)
+MagickExport int LocaleCompare(const char *p,const char *q)
 {
   if ((p == (char *) NULL) && (q == (char *) NULL))
     return(0);
@@ -1352,22 +1352,23 @@ MagickExport long LocaleCompare(const char *p,const char *q)
   if (q == (char *) NULL)
     return(1);
 #if defined(MAGICKCORE_HAVE_STRCASECMP)
-  return((long) strcasecmp(p,q));
+  return(strcasecmp(p,q));
 #else
   {
     register int
       c,
-      d,
-      i;
+      d;
 
-    for (i=0; ; i++)
+    for ( ; ; )
     {
-      c=(int) p[i];
-      d=(int) q[i];
-      if ((c == '\0') || (AsciiMap[c] != AsciiMap[d]))
+      c=(int) *((unsigned char *) p);
+      d=(int) *((unsigned char *) q);
+      if ((c == 0) || (AsciiMap[c] != AsciiMap[d]))
         break;
+      p++;
+      q++;
     }
-    return((long) AsciiMap[c]-AsciiMap[d]);
+    return(AsciiMap[c]-(int) AsciiMap[d]);
   }
 #endif
 }
@@ -1429,7 +1430,7 @@ MagickExport void LocaleLower(char *string)
 %
 %  The format of the LocaleNCompare method is:
 %
-%      long LocaleNCompare(const char *p,const char *q,const size_t n)
+%      int LocaleNCompare(const char *p,const char *q,const size_t n)
 %
 %  A description of each parameter follows:
 %
@@ -1440,15 +1441,14 @@ MagickExport void LocaleLower(char *string)
 %    o length: the number of characters to compare in strings p & q.
 %
 */
-MagickExport long LocaleNCompare(const char *p,const char *q,
-  const size_t length)
+MagickExport int LocaleNCompare(const char *p,const char *q,const size_t length)
 {
   if (p == (char *) NULL)
     return(-1);
   if (q == (char *) NULL)
     return(1);
 #if defined(MAGICKCORE_HAVE_STRNCASECMP)
-  return((long) strncasecmp(p,q,length));
+  return(strncasecmp(p,q,length));
 #else
   {
     register int
@@ -1456,20 +1456,20 @@ MagickExport long LocaleNCompare(const char *p,const char *q,
       d;
 
     register size_t
-      n;
+      i;
 
-    for (n=length; n != 0; n--)
+    for (i=length; i != 0; i--)
     {
-      c=(int) *p;
-      d=(int) *q;
+      c=(int) *((unsigned char *) p);
+      d=(int) *((unsigned char *) q);
       if (AsciiMap[c] != AsciiMap[d])
-        return(AsciiMap[c]-AsciiMap[d]);
-      if (c == '\0')
-        return(0L);
+        return(AsciiMap[c]-(int) AsciiMap[d]);
+      if (c == 0)
+        return(0);
       p++;
       q++;
     }
-    return(0L);
+    return(0);
   }
 #endif
 }
@@ -2395,7 +2395,7 @@ MagickExport MagickBooleanType SubstituteString(char **string,
         /*
           Make room for the replacement string.
         */
-        offset=p-(*string);
+        offset=(ssize_t) (p-(*string));
         extent=strlen(*string)+replace_extent-search_extent+1;
         *string=(char *) ResizeQuantumMemory(*string,extent+MaxTextExtent,
           sizeof(*p));
